@@ -13,13 +13,16 @@ SET enable_seqscan = off;
 SET enable_indexscan = off;
 SET enable_bitmapscan = on;
 
+\pset format unaligned
 EXPLAIN (COSTS OFF)
 SELECT content, pgroonga_score(tableoid, ctid)
   FROM memos
  WHERE content &@~
        ('090-12345678',
         ARRAY[5],
-        'pgrn_index')::pgroonga_full_text_search_condition;
+        'pgrn_index')::pgroonga_full_text_search_condition
+\g |sed -r -e "s/('.+'|ROW.+)::pgroonga/pgroonga/g"
+\pset format aligned
 
 SELECT content, pgroonga_score(tableoid, ctid)
   FROM memos
