@@ -6,7 +6,7 @@ CREATE TABLE synonyms (
 INSERT INTO synonyms VALUES ('Mroonga', ARRAY['Mroonga', 'Groonga MySQL']);
 INSERT INTO synonyms VALUES ('PGroonga', ARRAY['PGroonga', 'Groonga PostgreSQL']);
 
-SELECT pgroonga.query_expand('synonyms', 'term', 'synonyms',
+SELECT pgroonga_query_expand('synonyms', 'term', 'synonyms',
                              'Ruby (Mroonga OR PGroonga)');
 
 DROP TABLE synonyms;
