@@ -7,6 +7,6 @@ CREATE INDEX synonyms_term_index ON synonyms (term);
 
 INSERT INTO synonyms VALUES ('Groonga', ARRAY['Groonga', 'Senna']);
 
-SELECT pgroonga.query_expand('synonyms', 'term', 'synonyms', 'Groonga');
+SELECT pgroonga_query_expand('synonyms', 'term', 'synonyms', 'Groonga');
 
 DROP TABLE synonyms;
