@@ -9,7 +9,6 @@
 #include "pgrn-value.h"
 
 static grn_ctx *ctx = &PGrnContext;
-static struct PGrnBuffers *buffers = &PGrnBuffers;
 
 void
 PGrnCreateSourcesTable(PGrnCreateData *data)
@@ -118,10 +117,9 @@ PGrnCreateLexicon(PGrnCreateData *data)
 	grn_obj *type;
 	grn_obj *lexicon;
 	grn_obj *tokenizer = NULL;
-	grn_obj *normalizer = NULL;
-	grn_obj *tokenFilters = &(buffers->tokenFilters);
+	grn_obj *normalizers = NULL;
+	grn_obj *tokenFilters = NULL;
 
-	GRN_BULK_REWIND(tokenFilters);
 	switch (data->attributeTypeID)
 	{
 	case GRN_DB_TEXT:
@@ -138,7 +136,7 @@ PGrnCreateLexicon(PGrnCreateData *data)
 		data->forPrefixSearch)
 	{
 		const char *tokenizerName = NULL;
-		const char *normalizerName = PGRN_DEFAULT_NORMALIZER;
+		const char *normalizersName = PGRN_DEFAULT_NORMALIZERS;
 		PGrnOptionUseCase useCase = PGRN_OPTION_USE_CASE_UNKNOWN;
 
 		if (data->forFullTextSearch)
@@ -158,11 +156,13 @@ PGrnCreateLexicon(PGrnCreateData *data)
 		}
 
 		PGrnApplyOptionValues(data->index,
+							  data->i,
 							  useCase,
 							  &tokenizer, tokenizerName,
-							  &normalizer, normalizerName,
-							  tokenFilters,
-							  &flags);
+							  &normalizers, normalizersName,
+							  &tokenFilters,
+							  &flags,
+							  NULL);
 	}
 	else
 	{
@@ -177,7 +177,7 @@ PGrnCreateLexicon(PGrnCreateData *data)
 							  flags,
 							  type,
 							  tokenizer,
-							  normalizer,
+							  normalizers,
 							  tokenFilters);
 	GRN_PTR_PUT(ctx, data->lexicons, lexicon);
 }
@@ -201,6 +201,20 @@ PGrnCreateIndexColumn(PGrnCreateData *data)
 			flags |= GRN_OBJ_WITH_SECTION;
 		}
 	}
+	{
+		grn_obj *tokenizer = NULL;
+		grn_obj *normalizers = NULL;
+		grn_obj *tokenFilters = NULL;
+		grn_table_flags tableFlags = 0;
+		PGrnApplyOptionValues(data->index,
+							  data->i,
+							  PGRN_OPTION_USE_CASE_UNKNOWN,
+							  &tokenizer, NULL,
+							  &normalizers, NULL,
+							  &tokenFilters,
+							  &tableFlags,
+							  &flags);
+	}
 	PGrnCreateColumn(data->index,
 					 lexicon,
 					 PGrnIndexColumnName,
