@@ -1,6 +1,6 @@
 #pragma once
 
-#include <postgres.h>
+#include "pgrn-compatible.h"
 
 #include <access/heapam.h>
 #include <access/htup_details.h>
@@ -9,8 +9,6 @@
 #endif
 #include <catalog/pg_tablespace.h>
 
-#include "pgrn-compatible.h"
-
 typedef struct {
 	LOCKMODE lockMode;
 	Relation tablespaces;
@@ -22,7 +20,7 @@ PGrnTablespaceIteratorInitialize(PGrnTablespaceIterator *iterator,
 								 LOCKMODE lockMode)
 {
 	iterator->lockMode = lockMode;
-	iterator->tablespaces = heap_open(TableSpaceRelationId, lockMode);
+	iterator->tablespaces = pgrn_table_open(TableSpaceRelationId, lockMode);
 	iterator->scan = pgrn_table_beginscan_catalog(iterator->tablespaces,
 												  0,
 												  NULL);
@@ -51,6 +49,6 @@ static inline void
 PGrnTablespaceIteratorFinalize(PGrnTablespaceIterator *iterator)
 {
 	heap_endscan(iterator->scan);
-	heap_close(iterator->tablespaces, iterator->lockMode);
+	pgrn_table_close(iterator->tablespaces, iterator->lockMode);
 }
 
